@@ -168,7 +168,7 @@ class FPLAnalytics:
         basic_info_cols = ['id', 'first_name', 'second_name', 'team', 'web_name', 'element_type', 'now_cost']
         game_stats = [z['name'] for z in raw_data['element_stats']]
         extra_stats = ['matches', 'points_per_game', 'event_points', 'total_points', 'corners_and_indirect_freekicks_order', 'direct_freekicks_order', 'penalties_order']
-        summaryCols = ['element', 'web_name', 'short_name', 'first_name', 'second_name', 'now_cost'] + game_stats + extra_stats + ['strength_attack_home', 'strength_attack_away', 'strength_defence_home', 'strength_defence_away']
+        summaryCols = ['element', 'web_name', 'short_name', 'first_name', 'second_name', 'now_cost', 'element_type', 'status', 'news'] + game_stats + extra_stats + fpl_stat_cols + ['strength_attack_home', 'strength_attack_away', 'strength_defence_home', 'strength_defence_away']
         playerCols = basic_info_cols + game_stats + extra_stats + fpl_stat_cols + ['status', 'news']
 
         playerInfo = pd.DataFrame(raw_data['elements'])
@@ -265,30 +265,33 @@ class FPLAnalytics:
         combPlayerdetails = pd.merge(playerDetails, playerSummary, how = 'inner', left_on='element', right_on='element')
 
         return combPlayerdetails
-    
-    def convertSpecialChar(wrd):
-        return unidecode.unidecode(wrd)
 
     def findPlayer(self, pattern):
         
         players = [p.strip() for p in pattern.split(' ')]
         stats = self.getPlayerSummary()
-        stats['web_name_decode'] = stats[['web_name']].apply(lambda x: convertSpecialChar(x['web_name']), axis = 1)
+        stats['web_name_decode'] = stats[['web_name']].apply(lambda x: unidecode.unidecode(x['web_name']), axis = 1)
+        stats['full_name_decode'] = stats[['full_name']].apply(lambda x: unidecode.unidecode(x['full_name']), axis = 1)
         
         result = pd.DataFrame()
         for p in players:
             df = stats[stats['web_name_decode'].str.match(p, flags=re.IGNORECASE)]
+            if df.shape[0] == 0:
+                df = stats[stats['full_name_decode'].str.match(p, flags=re.IGNORECASE, regex=True)]
             if df.shape[0] == 0:
                 df = stats[stats['web_name_decode'].str.contains(p, flags=re.IGNORECASE, regex=True)]
             result = pd.concat([result, df])
         return result
 
     def getPlayerUnderStats(self):
-
-        obj = GetStats()
-        obj.get_league_players()
-        understats = obj.players[['player_name', 'xG', 'xA', 'shots', 'key_passes', 'npg', 'npxG', 'xGChain', 'xGBuildup']]
-        return understats
+        cols = ['player_name', 'xG', 'xA', 'shots', 'key_passes', 'npg', 'npxG', 'xGChain', 'xGBuildup']
+        try:
+            obj = GetStats()
+            obj.get_league_players()
+            understats = obj.players[['player_name', 'xG', 'xA', 'shots', 'key_passes', 'npg', 'npxG', 'xGChain', 'xGBuildup']]
+            return understats
+        except:
+            return pd.DataFrame(columns = cols)
 
     def getEventDetails(self, eventId):
 
